@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-#Last-modified: 17 Nov 2014 10:05:12 AM
+#Last-modified: 11 Dec 2014 03:56:18 PM
 
 
         #############################################################################
@@ -756,11 +756,13 @@ class Predictor(object):
             # SCLASS
             os.system('mkdir '+prefix+'/clusters')
             cmd = [os.environ['SCLASSEXE'], '-b', prefix+'/bp.out', '-c', prefix+'/clusters', '-e', prefix, '-f', prefix+'/fe.out', '-p', prefix+'/bprob.out', '-s', faname]
-            # print ' '.join(cmd)
+            #print ' '.join(cmd)
             p = Popen(cmd,stdin = None, stdout = PIPE, stderr = PIPE)
             pstdout, pstderr = p.communicate()
-            if pstderr and not pstderr.startswith('Read'):
-                raise IOError("ERROR: {0} sampling failed for {1}.".format(os.environ['SCLASSEXE'],tfastc.name))
+            #if not pstderr.startswith('Read'):
+                #sys.stderr.write(pstderr)
+            if not os.path.isfile(prefix+"/clusters/c01.ccentroid.ct"):
+                raise IOError("ERROR: {0} clustering failed for {1}.".format(os.environ['SCLASSEXE'],tfastc.name))
             if debug: 
                 stop2 = time.time()
                 print >> sys.stderr, tfastc.name,stop1-start,stop2-stop1
